<?php
/**
 * @file
 * Contains support form for miniOrange 2FA Login Module.
 */

 /**
 * Showing Support form info.
 */
 function mo_auth_login_settings($form, &$form_state) {
  if (! MoAuthUtilities::isCustomerRegistered()) {
    $form['header'] = array(
      '#markup' => '<center><h3>You need to register with miniOrange before using this module.</h3></center>',
    );
    return $form;
  }

     $form['header_top_style_1'] = array(
	 	'#markup' => '<div class="mo_saml_table_layout_1">',
     );

     $form['header_top_style_2'] = array(
	 	'#markup' => '<div class="mo_saml_table_layout container">'
	 );

     $loginSettings = new MoAuthLoginSettings();

  $form['mo_auth_enable_two_factor'] = array(
  	'#type' => 'checkbox',
  	'#value' => $loginSettings->getEnable2Factor(),
  	'#prefix' => '<div><div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Enable Two-Factor module</div></div><div class="mo2f-info">',
  	'#suffix' => '</div></div>',
  	'#title' => t('Enable Two-Factor plugin. <span style="color:red;">(If you disable this checkbox, Two-Factor module will not be invoked for any user during login.)</span>'),
  );

  $license_type = variable_get('mo_auth_2fa_license_type', 'DEMO');
  $is_free = $license_type == 'PREMIUM' || $license_type == 'DRUPAL_2FA_PLUGIN' ? FALSE : TRUE;

  $is_free_class = $is_free ? " mo2f-grayed-out" : "";
  $form['mo_auth_enforce_inline_registration'] = array(
  	'#type' => 'checkbox',
  	'#value' => $loginSettings->getEnforceInlineRegistration(),
  	'#prefix' => '<div><div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Invoke Inline Registration to setup 2nd factor for users</div>
        <div style="float:right;display:inline-block;color:#0073aa;"><a href="?q=admin/config/people/mo_auth/licensing"><b>PREMIUM*</b></a></div></div><div class="mo2f-info ' . $is_free_class . '">',
  	'#suffix' => '</div></div>',
  	'#disabled' => $is_free,
  	'#title' => t('Enforce 2 Factor registration for users at login time.'),
  );

     $form['markup_idp_login_note'] = array(
         '#markup' => '<div class="mo_saml_highlight_background_note"><b>Note: </b>By default 2nd Factor is enabled after password authentication.
            If you do not want to remember passwords anymore and just login with 2nd Factor, please select below option.</div></br>',
     );

  $form['mo_auth_two_factor_instead_password'] = array(
    '#type' => 'checkbox',
    '#value' => $loginSettings->getEnableOTPinsteadPassword(),
    '#prefix' => '<div class="mo2f-setup-header"><div class="mo2f-setup-header-top-left">Select Login Screen Options</div><div style="float:right;display:inline-block;color:#0073aa;"><a href="?q=admin/config/people/mo_auth/licensing"><b>PREMIUM*</b></a></div></div><div class="mo2f-info ' . $is_free_class . '"><div class="mo2f-info">',
    '#suffix' => '</div></div>',
    '#disabled' => $is_free,
    '#title' => t('Login with 2nd Factor only (No password required.)'),
    '#description' => 'NOTE: To use this feature make sure you have enabled the "ENFORCE 2 FACTOR REGISTRATION FOR USERS AT LOGIN TIME" feature',
  );

  $form['actions'] = array('#type' => 'actions');
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save Settings'),
  );

     $form['markup_idp_attr_header_top_div_close'] = array('#markup' => '</div>',
     );

     $form['markup_idp_attr_header_top_support'] = array('#markup' => '<div class="mo_saml_table_layout_support_1">',
     );

     $form['markup_support_1'] = array(
         '#markup' => '<h3><b>Support:</b></h3></span></h3><div>Need any help? Just send us a query so we can help you.<br /></div>',
     );

     $form['miniorange_saml_email_address_support'] = array(
         '#type' => 'textfield',
         '#attributes' => array('style' => 'width:100%','placeholder' => 'Enter your Email'),
     );

     $form['miniorange_saml_phone_number_support'] = array(
         '#type' => 'textfield',
         '#attributes' => array('style' => 'width:100%','placeholder' => 'Enter your phone number with country code (+1)'),
     );

     $form['miniorange_saml_support_query_support'] = array(
         '#type' => 'textarea',
         '#cols' => '10',
         '#rows' => '5',
         '#attributes' => array('style' => 'width:100%','placeholder' => 'Write your query here.'),
     );

     $form['miniorange_saml_support_submit_click'] = array(
         '#type' => 'submit',
         '#value' => t('Submit Query'),
         '#submit' => array('miniorange_2fa_send_query'),
     );

     $form['miniorange_saml_support_note'] = array(
         '#markup' => '<div>If you want custom features in the plugin, just drop an email to <a href="mailto:info@miniorange.com">info@miniorange.com</a></div></div></div>'
     );

  return $form;
 }

 /**
  * Send support query.
  */
 function mo_auth_login_settings_submit($form, &$form_state) {
   $form_state['rebuild'] = TRUE;
   $enable2Factor = FALSE;
   $enforceInlineRegistration = FALSE;
   $enableOTP_instead_password = FALSE;

   if (array_key_exists('mo_auth_enable_two_factor', $form_state['input'])) {
       $enable2Factor = TRUE;
   }
   if (array_key_exists('mo_auth_two_factor_instead_password', $form_state['input'])) {
     $enableOTP_instead_password = TRUE;
     $enforceInlineRegistration = TRUE;
   }
   if (array_key_exists('mo_auth_enforce_inline_registration', $form_state['input'])) {
     $enforceInlineRegistration = TRUE;
   }

   $loginSettings = MoAuthLoginSettings::withValues($enable2Factor, $enforceInlineRegistration, $enableOTP_instead_password);
   $loginSettings->updateLoginSettings();
   drupal_set_message(t("Login settings updated."), 'status');
 }

/**
 * Send support query.
 */
function miniorange_2fa_send_query($form, &$form_state)
{
    $email = $form['miniorange_saml_email_address_support']['#value'];
    $phone = $form['miniorange_saml_phone_number_support']['#value'];
    $query = $form['miniorange_saml_support_query_support']['#value'];
    $support = new Miniorange2FASupport($email, $phone, $query);
    $support_response = $support->sendSupportQuery();
    if($support_response) {
        drupal_set_message(t('Your support query has been sent successfully. We will get back to you soon.'));
    }
    else {
        drupal_set_message(t('Error sending support query. Please try again.'), 'error');
    }
}